@@ -33,11 +33,13 @@
  */
 
 #include <config.h>
+
+#include <glib/gi18n-lib.h>
+
 #include "gnome-authentication-manager.h"
 #include "gnome-authentication-manager-private.h"
 
 #include <gnome.h>
-#include <libgnome/gnome-i18n.h>
 #include "gnome-password-dialog.h"
 #include <libgnomevfs/gnome-vfs-module-callback.h>
 #include <libgnomevfs/gnome-vfs-standard-callbacks.h>
@@ -295,6 +297,7 @@ construct_full_password_dialog (const GnomeVFSModuleCallbackFullAuthenticationIn
 		g_string_append_printf (name, "/%s", in_args->object);
 	}
 	if (in_args->domain != NULL) {
+		/* Translators: "You must log in to acces user@server.com/share domain MYWINDOWSDOMAIN." */
 		message = g_strdup_printf (_("You must log in to access %s domain %s\n"), name->str, in_args->domain);
 	} else {
 		message = g_strdup_printf (_("You must log in to access %s\n"), name->str);
